#  hypocycloid.rb
# ---------------------------------------------------------------------------
#
#  Hypocycloid cam generator
#
#  Generate 2D profiles of hypocycloid cams for cycloid drives.
#
# ---------------------------------------------------------------------------
#  Copyuright 2013, Daniel A. Rathbun ( translated from the Python )
#  Copyright  2009, Alex Lait ( http://www.zincland.com/hypocycloid )
# ---------------------------------------------------------------------------
#  License  :	GPL
#
#  WARNING!  IF you edit and create your OWN edition from this code ...
#            CHANGE THE TOPLEVEL MODULE NAME ! "Aal" belongs to Dan Rathbun!
#
# ---------------------------------------------------------------------------
#  References:
#
#  Formulas to describe a hypocycloid cam:
#    http://gears.ru/transmis/zaprogramata/2.139.pdf
#
#  Insperational thread on CNCzone
#    http://www.cnczone.com/forums/showthread.php?t=72261
#
#  Formulas for calculating the pressure angle and finding the limit circles
#    http://imtuoradea.ro/auo.fmte/files-2007/MECATRONICA_files/Anamaria_Dascalescu_1.pdf
#
# ---------------------------------------------------------------------------
#  Notes:
#
#  Does not currently do ANY checking for sane input values and it
#  is possible to create un-machinable cams, use at your own risk
#
#  Suggestions:
#   * Eccentricity should not be more than the pin radius.
#   * Has not been tested with negative values, may have interesting results!
#
# ---------------------------------------------------------------------------

require('sketchup.rb')
require('extensions.rb')

module Aal  #  <---<<  Dan Rathbun's proprietary toplevel namespace.

  module Hypocycloid
  
    @@plugin = SketchupExtension.new('Hypocycloid','Aal/Hypocycloid/hypocycloid.rb')
    
    @@plugin.version = '1.0.0'

    @@plugin.creator = 'Daniel A. Rathbun'
    @@plugin.copyright = '2013, released under the GPL'

    @@plugin.description= 'Generate 2D profiles of hypocycloid cams for cycloid drives.'
    
    Sketchup.register_extension(@@plugin,true)

  end # module Hypocycloid

end # outer module
